==> announcementcenter-v7.0.1-frama.tar.gz: announcementcenter/l10n/ar.js <==
OC.L10N.register(
    "announcementcenter",
    {
    "You announced “{announcement}”" : "أنت أعلنتَ ”{announcement}“",
    "{actor} announced “{announcement}”" : "{actor} أعلَنَ ”{announcement}“",
    "You posted an announcement" : "لقد قمت بنشر إعلان",
    "{actor} posted an announcement" : "{actor} قام بنشر إعلان",
    "The announcement does not exist anymore" : "الإعلان لم يعد موجوداً",
    "An <strong>announcement</strong> is posted by an administrator" : "قام مشرف بنشر <strong>إعلان</strong> ",
    "The subject is too long or empty" : "الموضوع طويل جدا أو فارغ",
    "Announcements" : "الإعلانات",
    "Read more" : "أقرأ أكثر",
    "{author}, {time}" : "{author}, {time}",
    "{user} announced {announcement}" : "{user} أعلَنَ {announcement}",
    "{user} announced “{announcement}”" : "{user} أعلَنَ ”{announcement}“",
    "Announcement center" : "مركز الإعلانات",
    "This app allows admins to post announcements." : "هذا التطبيق يسمح للمشرفين بإرسال الإعلانات.",
    "Announce your maintenance window 🎛️, introduce a new colleague 👤 or make sure everyone knows about the big event next month 📅\n\n🖌️ Markdown support\n\n📑 Comments including @-mentions\n\n👪 Group permissions\n\n⭕ Dashboard integration\n\n⚡ Activities integration\n\n🔔 Notifications integration" : "أعلِن عن نافذة الصيانة الخاصة بك 🎛️، أو قدم زميلًا جديدًا 👤 أو تأكد من أن الجميع يعرف عن الحدث الكبير الشهر المقبل 📅\n\n🖌️ دعم التنسيق بصيغة \"Markdown\"\n\n📑 التعليقات تتضمن @-الإشارات\n\n👪 أذونات المجموعة\n\n⭕ تكامل لوحة القيادة\n\n⚡ تكامل الأنشطة\n\n🔔 تكامل الإشعارات",
    "These groups will be able to post announcements." : "هذه المجموعات ستملك الصلاحية لنشر الاعلانات",
    "Create activities by default" : "أنشِئْ النشاطات افتراضياً",
    "Create notifications by default" : "أنشِئْ الاشعارات افتراضياً",
    "Send emails by default" : "أرسل إيميل ما لم يحدد غير ذلك",
    "Allow comments by default" : "إسمح بالتعليقات ما لم يحدد غير ذلك",
    "Setting changed" : "تمّ تغيير الإعداد",
    "An error occurred while changing the setting" : "حدث خطأ أثناء تغيير الإعدادات",
    "No announcements" : "لا توجد اعلانات",
    "There are currently no announcements …" : "لا توجد أي إعلانات حاليّاً",
    "Comments" : "تعليقات",
    "Clear notifications" : "مسح الإخطارات",
    "Delete announcement" : "حذف الاعلانات",
    "seconds ago" : "منذ ثوان مضت",
    "visible to everyone" : "مرئي للجميع",
    "visible to group {name}" : "مرئي لمجموعة \"{name}\"",
    "visible to groups {name1} and {name2}" : "مرئي لمجموعتي \"{name1}\" و \"{name2}\"",
    "scheduled at {time}" : "مجدولة في {time}",
    ", " : "،",
    "An error occurred while removing the notifications of the announcement" : "حدث خطأ أثناء إزالة إخطارات الإعلان",
    "An error occurred while deleting the announcement" : "حدث خطأ أثناء حذف الإعلان",
    "_%n comment_::_%n comments_" : ["%n تعليقات","%n تعليق","%n تعليق","%n تعليقات","%n تعليقات","%n تعليقات"],
    "New announcement subject" : "موضوع إعلان جديد",
    "Write announcement text, Markdown can be used …" : "اكتب نص إعلان، يمكنك استعمال تنسيق \"Markdown\" ...",
    "Announce" : "أعلِن",
    "Create activities" : "إنشاء أنشطة",
    "Create notifications" : "إنشاء اشعارات",
    "Send emails" : "إرسال إيميل",
    "Allow comments" : "السماح بنشر تعليقات",
    "Visibility" : "الرؤية  ",
    "Everyone" : "الكل",
    "These groups will be able to see the announcement. If no group is selected, all users can see it." : "هذه المجموعات سترى الاعلانات. اذا لم يتم اختيار مجموعة محددة فإن جميع المستخدين سيرونها.",
    "Schedule announcement time" : "جدولة وقت الإعلان",
    "Schedule deletion time" : "جدولة وقت الحذف",
    "An error occurred while posting the announcement" : "حدث خطأ أثناء نشر الإعلان",
    "{author}, {timestamp}" : "{author}، {timestamp}"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> announcementcenter-v7.1.0-frama.tar.gz: announcementcenter/l10n/ar.js <==
OC.L10N.register(
    "announcementcenter",
    {
    "You announced “{announcement}”" : "أنت أعلنتَ ”{announcement}“",
    "{actor} announced “{announcement}”" : "{actor} أعلَنَ ”{announcement}“",
    "You posted an announcement" : "لقد قمت بنشر إعلان",
    "{actor} posted an announcement" : "{actor} قام بنشر إعلان",
    "The announcement does not exist anymore" : "الإعلان لم يعد موجوداً",
    "An <strong>announcement</strong> is posted by an administrator" : "قام مسؤول النظام بنشر <strong>إعلان</strong> ",
    "The subject is too long or empty" : "الموضوع طويل جدا أو فارغ",
    "Announcements" : "الإعلانات",
    "Read more" : "أقرأ أكثر",
    "{author}, {time}" : "{author}, {time}",
    "{user} announced {announcement}" : "{user} أعلَنَ {announcement}",
    "{user} announced “{announcement}”" : "{user} أعلَنَ ”{announcement}“",
    "Announcement center" : "مركز الإعلانات",
    "This app allows admins to post announcements." : "هذا التطبيق يسمح للمديرين بإرسال الإعلانات.",
    "Announce your maintenance window 🎛️, introduce a new colleague 👤 or make sure everyone knows about the big event next month 📅\n\n🖌️ Markdown support\n\n📑 Comments including @-mentions\n\n👪 Group permissions\n\n⭕ Dashboard integration\n\n⚡ Activities integration\n\n🔔 Notifications integration" : "أعلِن عن نافذة الصيانة الخاصة بك 🎛️، أو قدم زميلًا جديدًا 👤 أو تأكد من أن الجميع يعرف عن الحدث الكبير الشهر المقبل 📅\n\n🖌️ دعم التنسيق بصيغة \"Markdown\"\n\n📑 التعليقات تتضمن @-الإشارات\n\n👪 أذونات المجموعة\n\n⭕ تكامل لوحة القيادة\n\n⚡ تكامل الأنشطة\n\n🔔 تكامل الإشعارات",
    "These groups will be able to post announcements." : "هذه المجموعات ستملك الصلاحية لنشر الاعلانات",
    "Create activities by default" : "أنشِئْ النشاطات افتراضياً",
    "Create notifications by default" : "أنشِئْ الاشعارات افتراضياً",
    "Send emails by default" : "أرسل إيميل ما لم يحدد غير ذلك",
    "Allow comments by default" : "إسمح بالتعليقات ما لم يحدد غير ذلك",
    "Setting changed" : "تمّ تغيير الإعداد",
    "An error occurred while changing the setting" : "حدث خطأ أثناء تغيير الإعدادات",
    "No announcements" : "لا توجد اعلانات",
    "There are currently no announcements …" : "لا توجد أي إعلانات حاليّاً",
    "Comments" : "تعليقات",
    "Clear notifications" : "مسح الإخطارات",
    "Delete announcement" : "حذف الاعلانات",
    "seconds ago" : "منذ ثوان مضت",
    "visible to everyone" : "مرئي للجميع",
    "visible to group {name}" : "مرئي لمجموعة \"{name}\"",
    "visible to groups {name1} and {name2}" : "مرئي لمجموعتي \"{name1}\" و \"{name2}\"",
    "scheduled at {time}" : "مجدولة في {time}",
    ", " : "،",
    "An error occurred while removing the notifications of the announcement" : "حدث خطأ أثناء إزالة إخطارات الإعلان",
    "An error occurred while deleting the announcement" : "حدث خطأ أثناء حذف الإعلان",
    "_%n comment_::_%n comments_" : ["%n تعليقات","%n تعليق","%n تعليق","%n تعليقات","%n تعليقات","%n تعليقات"],
    "New announcement subject" : "موضوع إعلان جديد",
    "Write announcement text, Markdown can be used …" : "اكتب نص إعلان، يمكنك استعمال تنسيق \"Markdown\" ...",
    "Announce" : "أعلِن",
    "Create activities" : "إنشاء أنشطة",
    "Create notifications" : "إنشاء اشعارات",
    "Send emails" : "إرسال إيميل",
    "Allow comments" : "السماح بنشر تعليقات",
    "Visibility" : "الرؤية  ",
    "Everyone" : "الكل",
    "These groups will be able to see the announcement. If no group is selected, all users can see it." : "هذه المجموعات سترى الاعلانات. اذا لم يتم اختيار مجموعة محددة فإن جميع المستخدين سيرونها.",
    "Schedule announcement time" : "جدولة وقت الإعلان",
    "Schedule deletion time" : "جدولة وقت الحذف",
    "An error occurred while posting the announcement" : "حدث خطأ أثناء نشر الإعلان",
    "{author}, {timestamp}" : "{author}، {timestamp}"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
